;rbsp_efw_vxb_subtract_crib
;
;Creates vxB subtracted tplot variables
;
;
;requires: SSL THEMIS software
;			 http://themis.ssl.berkeley.edu/software.shtml
;
;
;Created by Aaron Breneman, UMN, Dec 2012
;			email: awbrenem@gmail.com





;initialize RBSP environment
	rbsp_efw_init
	!rbsp_efw.user_agent = ''


;set desired probe
	probe = 'a'
	rbspx = 'rbsp'+probe

;set time of interest to a single day
	date = '2012-10-13'	; UTC.
	duration = 1	; days.
	timespan, date, duration


;Set other quantities
	integration=0 ; for looking at integration data
	get_support_data = 0 ; include support data? 0=no, 1=yes
	suffix = ''
	spinperiod = 11. ;seconds	
	type='calibrated' ;use ADC (raw) numbers or physical (calibrated) units?



;Load predicted and definitive sc positions and velocities
	;rbsp_load_spice_predict   ;(need to manually download these)
	rbsp_load_spice_kernels




	;Load mag data (loads hires UVW at the moment)
	rbsp_load_emfisis,probe=probe,/quicklook  ;load this for the mag model subtract


;MANUALLY LOAD EMFISIS GEI FILE		
		;cdf_leap_second_init
		;files = '~/data/rbsp/emfisis/Flight/RBSP-A/Quick-Look/2012/10/13/rbsp-a_magnetometer_hires-gei_emfisis-Quick-Look_20121013_v1.2.1.cdf'
		;cdf2tplot,files=files
		;;Returns "Mag"
		;get_data,'Mag',data=dd,dlimits=dlim,limits=lim
		;store_data,rbspx+'_emfisis_quicklook_Mag',data=dd,dlimits=dlim,limits=lim


;Despin the data
	rbsp_uvw_to_mgse,probe,rbspx+'_emfisis_quicklook_Mag',/no_spice_load
	

;Downsample data to spinperiod
	rbsp_downsample,[rbspx+'_emfisis_quicklook_Mag_mgse',$
					 rbspx+'_emfisis_quicklook_Magnitude'],$
					 1/spinperiod,/nochange



;Transform data to GSE
;	cotrans,rbspx+'_emfisis_quicklook_Mag_mgse',rbspx+'_mag_gse',/GEI2GSE



;Load Esvy data in MGSE 
	rbsp_load_efw_esvy_mgse,probe=probe,/no_spice_load
	rbsp_downsample,rbspx+'_efw_esvy_mgse',1/spinperiod,/nochange
	
	

;load position and velocity data
	rbsp_load_spice_state,probe=probe,coord='gse',/no_spice_load  




;Get spin-axis pointing vector. Used for rotation from GSE -> MGSE	
	time2=time_double(date) ; first get unix time double for beginning of day

	;Grab first and last time of day
	time2 = [time2,time2+86399.]
	time3=time_string(time2, prec=6) ; turn it back into a string for ISO conversion
	strput,time3,'T',10 ; convert TPLOT time string 'yyyy-mm-dd/hh:mm:ss.msec' to ISO 'yyyy-mm-ddThh:mm:ss.msec'
	cspice_str2et,time3,et2 ; convert ISO time string to SPICE ET

	
	cspice_pxform,'RBSP'+strupcase(probe)+'_SCIENCE','GSE',et2[0],pxform1
	cspice_pxform,'RBSP'+strupcase(probe)+'_SCIENCE','GSE',et2[1],pxform2
	
	wsc1=dblarr(3)
	wsc1[2]=1d
	wsc_GSE1=dblarr(3)
	
	wsc2=dblarr(3)
	wsc2[2]=1d
	wsc_GSE2=dblarr(3)
	
	; Calculate the modified MGSE directions	
	wsc_GSE1 = pxform1 ## wsc1  ;start of day
	wsc_GSE2 = pxform2 ## wsc2  ;end of day	
	
	
		
		
	;Now convert from GSE to MGSE. For now I'll just use the Wgse value
	;at the beginning of the day. The Wgse vector direction probably won't
	;change by more than 1 degree during a day. 

	;rbsp_gse2mgse,rbspx+'_mag_gse',reform(wsc_GSE1),newname=rbspx+'_mag_mgse'
	rbsp_gse2mgse,rbspx+'_state_vel_gse',reform(wsc_GSE1),newname=rbspx+'_vel_mgse'
	
	



;Create the vxB subtracted variables
	
	rbsp_vxb_subtract,rbspx+'_vel_mgse',rbspx+'_emfisis_quicklook_Mag_mgse',rbspx+'_efw_esvy_mgse'

	get_data,'Esvy_mgse_vxb_removed',data=dat,dlimits=dlim,limits=lim
	store_data,rbspx+'_esvy_mgse_vxb_removed',data=dat,dlimits=dlim,limits=lim
	options,rbspx+'_esvy_mgse_vxb_removed','colors',[2,4,6]


	split_vec,rbspx+'_esvy_mgse_vxb_removed'
	split_vec,rbspx+'_efw_esvy_mgse'
	
	

	options,[rbspx+'_esvy_mgse_vxb_removed_x'],'ytitle','Ex!Cmgse!Cvxb!Cremoved!C[mV/m]'
	options,[rbspx+'_esvy_mgse_vxb_removed_y'],'ytitle','Ey!Cmgse!Cvxb!Cremoved!C[mV/m]'
	options,[rbspx+'_esvy_mgse_vxb_removed_z'],'ytitle','Ez!Cmgse!Cvxb!Cremoved!C[mV/m]'



	options,rbspx+'_efw_esvy_mgse','ysubtitle',''
	options,rbspx+'_efw_esvy_mgse_x','ysubtitle',''
	options,rbspx+'_efw_esvy_mgse_y','ysubtitle',''
	options,rbspx+'_efw_esvy_mgse_z','ysubtitle',''



	tplot_options,'xmargin',[20.,15.]
	tplot_options,'ymargin',[3,6]
	tplot_options,'xticklen',0.08
	tplot_options,'yticklen',0.02
	tplot_options,'xthick',2
	tplot_options,'ythick',2
	tplot_options,'labflag',-1	





	tplot_options,'title','Esvy with vxB removed'
	tplot,[rbspx+'_esvy_mgse_vxb_removed_x',$
		   rbspx+'_esvy_mgse_vxb_removed_y',$
		   rbspx+'_esvy_mgse_vxb_removed_z',$
		   rbspx+'_efw_esvy_mgse_x',$
		   rbspx+'_efw_esvy_mgse_y',$
		   rbspx+'_efw_esvy_mgse_z'],$
		   var_label = var_label


end
