;+
; NAME:	rbsp_split_fbk
;
;
; PURPOSE:	Split the filterbank data into separate tplot variables for 
;			each channel. Can also combine peak and average on a single panel         
;
; KEYWORDS:
;	probe = 'a' or 'b'  NOTE: single spacecraft only, does not accept ['a b']
;	combine -> set to combine peak and average onto a single plot
;
;
; CREATED: Aaron Breneman 11/07/2012
;
;-




pro rbsp_split_fbk,probe,combine=combine
	
	
;	fbk13_bins=['0.8-1.5Hz', '1.5-3Hz', '3-6Hz', '6-12Hz', '12-25Hz', '25-50Hz', $
;				'50-100Hz', '100-200Hz', '200-400Hz', '400-800Hz', $
;				'0.8-1.6kHz', '1.6-3.2kHz', '3.2-6.5kHz']
	fbk13_bins=['0.8-1.5', '1.5-3', '3-6', '6-12', '12-25', '25-50', $
				'50-100', '100-200', '200-400', '400-800', $
				'0.8-1.6', '1.6-3.2', '3.2-6.5']
	fbk7_bins=fbk13_bins[lindgen(7)*2]
	
	
	
	get_data,'rbsp'+probe +'_efw_fbk_13_fb1_pk',data=goo
	tst = size(goo,/dimensions)
	if tst ne 0 then begin
		store_data,'rbsp'+probe +'_fbk1_13pk_0',data={x:goo.x,y:goo.y[*,0]}
		store_data,'rbsp'+probe +'_fbk1_13pk_1',data={x:goo.x,y:goo.y[*,1]}
		store_data,'rbsp'+probe +'_fbk1_13pk_2',data={x:goo.x,y:goo.y[*,2]}
		store_data,'rbsp'+probe +'_fbk1_13pk_3',data={x:goo.x,y:goo.y[*,3]}
		store_data,'rbsp'+probe +'_fbk1_13pk_4',data={x:goo.x,y:goo.y[*,4]}
		store_data,'rbsp'+probe +'_fbk1_13pk_5',data={x:goo.x,y:goo.y[*,5]}
		store_data,'rbsp'+probe +'_fbk1_13pk_6',data={x:goo.x,y:goo.y[*,6]}
		store_data,'rbsp'+probe +'_fbk1_13pk_7',data={x:goo.x,y:goo.y[*,7]}
		store_data,'rbsp'+probe +'_fbk1_13pk_8',data={x:goo.x,y:goo.y[*,8]}
		store_data,'rbsp'+probe +'_fbk1_13pk_9',data={x:goo.x,y:goo.y[*,9]}
		store_data,'rbsp'+probe +'_fbk1_13pk_10',data={x:goo.x,y:goo.y[*,10]}
		store_data,'rbsp'+probe +'_fbk1_13pk_11',data={x:goo.x,y:goo.y[*,11]}
		store_data,'rbsp'+probe +'_fbk1_13pk_12',data={x:goo.x,y:goo.y[*,12]}
		

		options,'rbsp'+probe +'_fbk1_13pk_0','ytitle','pk!C'+fbk13_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_1','ytitle','pk!C'+fbk13_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_2','ytitle','pk!C'+fbk13_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_3','ytitle','pk!C'+fbk13_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_4','ytitle','pk!C'+fbk13_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_5','ytitle','pk!C'+fbk13_bins[5]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_6','ytitle','pk!C'+fbk13_bins[6]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_7','ytitle','pk!C'+fbk13_bins[7]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_8','ytitle','pk!C'+fbk13_bins[8]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_9','ytitle','pk!C'+fbk13_bins[9]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_10','ytitle','pk!C'+fbk13_bins[10]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_11','ytitle','pk!C'+fbk13_bins[11]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13pk_12','ytitle','pk!C'+fbk13_bins[12]+'!CkHz!C[mV/m]'

		
		options,'rbsp'+probe +'_fbk1_13pk_0','labels','RBSP'+probe+'!C  '+fbk13_bins[0]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_1','labels','RBSP'+probe+'!C  '+fbk13_bins[1]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_2','labels','RBSP'+probe+'!C  '+fbk13_bins[2]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_3','labels','RBSP'+probe+'!C  '+fbk13_bins[3]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_4','labels','RBSP'+probe+'!C  '+fbk13_bins[4]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_5','labels','RBSP'+probe+'!C  '+fbk13_bins[5]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_6','labels','RBSP'+probe+'!C  '+fbk13_bins[6]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_7','labels','RBSP'+probe+'!C  '+fbk13_bins[7]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_8','labels','RBSP'+probe+'!C  '+fbk13_bins[8]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_9','labels','RBSP'+probe+'!C  '+fbk13_bins[9]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13pk_10','labels','RBSP'+probe+'!C  '+fbk13_bins[10]+'!CkHz'
		options,'rbsp'+probe +'_fbk1_13pk_11','labels','RBSP'+probe+'!C  '+fbk13_bins[11]+'!CkHz'
		options,'rbsp'+probe +'_fbk1_13pk_12','labels','RBSP'+probe+'!C  '+fbk13_bins[12]+'!CkHz'	
	
	endif
	
	get_data,'rbsp'+probe +'_efw_fbk_13_fb2_pk',data=goo
	tst = size(goo,/dimensions)
	if tst ne 0 then begin
		store_data,'rbsp'+probe +'_fbk2_13pk_0',data={x:goo.x,y:goo.y[*,0]}
		store_data,'rbsp'+probe +'_fbk2_13pk_1',data={x:goo.x,y:goo.y[*,1]}
		store_data,'rbsp'+probe +'_fbk2_13pk_2',data={x:goo.x,y:goo.y[*,2]}
		store_data,'rbsp'+probe +'_fbk2_13pk_3',data={x:goo.x,y:goo.y[*,3]}
		store_data,'rbsp'+probe +'_fbk2_13pk_4',data={x:goo.x,y:goo.y[*,4]}
		store_data,'rbsp'+probe +'_fbk2_13pk_5',data={x:goo.x,y:goo.y[*,5]}
		store_data,'rbsp'+probe +'_fbk2_13pk_6',data={x:goo.x,y:goo.y[*,6]}
		store_data,'rbsp'+probe +'_fbk2_13pk_7',data={x:goo.x,y:goo.y[*,7]}
		store_data,'rbsp'+probe +'_fbk2_13pk_8',data={x:goo.x,y:goo.y[*,8]}
		store_data,'rbsp'+probe +'_fbk2_13pk_9',data={x:goo.x,y:goo.y[*,9]}
		store_data,'rbsp'+probe +'_fbk2_13pk_10',data={x:goo.x,y:goo.y[*,10]}
		store_data,'rbsp'+probe +'_fbk2_13pk_11',data={x:goo.x,y:goo.y[*,11]}
		store_data,'rbsp'+probe +'_fbk2_13pk_12',data={x:goo.x,y:goo.y[*,12]}
		

		options,'rbsp'+probe +'_fbk2_13pk_0','ytitle','pk!C'+fbk13_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_1','ytitle','pk!C'+fbk13_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_2','ytitle','pk!C'+fbk13_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_3','ytitle','pk!C'+fbk13_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_4','ytitle','pk!C'+fbk13_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_5','ytitle','pk!C'+fbk13_bins[5]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_6','ytitle','pk!C'+fbk13_bins[6]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_7','ytitle','pk!C'+fbk13_bins[7]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_8','ytitle','pk!C'+fbk13_bins[8]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_9','ytitle','pk!C'+fbk13_bins[9]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_10','ytitle','pk!C'+fbk13_bins[10]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_11','ytitle','pk!C'+fbk13_bins[11]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13pk_12','ytitle','pk!C'+fbk13_bins[12]+'!CkHz!C[mV/m]'

		
		options,'rbsp'+probe +'_fbk2_13pk_0','labels','RBSP'+probe+'!C  '+fbk13_bins[0]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_1','labels','RBSP'+probe+'!C  '+fbk13_bins[1]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_2','labels','RBSP'+probe+'!C  '+fbk13_bins[2]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_3','labels','RBSP'+probe+'!C  '+fbk13_bins[3]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_4','labels','RBSP'+probe+'!C  '+fbk13_bins[4]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_5','labels','RBSP'+probe+'!C  '+fbk13_bins[5]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_6','labels','RBSP'+probe+'!C  '+fbk13_bins[6]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_7','labels','RBSP'+probe+'!C  '+fbk13_bins[7]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_8','labels','RBSP'+probe+'!C  '+fbk13_bins[8]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_9','labels','RBSP'+probe+'!C  '+fbk13_bins[9]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13pk_10','labels','RBSP'+probe+'!C  '+fbk13_bins[10]+'!CkHz'
		options,'rbsp'+probe +'_fbk2_13pk_11','labels','RBSP'+probe+'!C  '+fbk13_bins[11]+'!CkHz'
		options,'rbsp'+probe +'_fbk2_13pk_12','labels','RBSP'+probe+'!C  '+fbk13_bins[12]+'!CkHz'	

		
	
	endif
	
	get_data,'rbsp'+probe +'_efw_fbk_7_fb1_pk',data=goo
	tst = size(goo,/dimensions)
	if tst ne 0 then begin
		store_data,'rbsp'+probe +'_fbk1_7pk_0',data={x:goo.x,y:goo.y[*,0]}
		store_data,'rbsp'+probe +'_fbk1_7pk_1',data={x:goo.x,y:goo.y[*,1]}
		store_data,'rbsp'+probe +'_fbk1_7pk_2',data={x:goo.x,y:goo.y[*,2]}
		store_data,'rbsp'+probe +'_fbk1_7pk_3',data={x:goo.x,y:goo.y[*,3]}
		store_data,'rbsp'+probe +'_fbk1_7pk_4',data={x:goo.x,y:goo.y[*,4]}
		store_data,'rbsp'+probe +'_fbk1_7pk_5',data={x:goo.x,y:goo.y[*,5]}
		store_data,'rbsp'+probe +'_fbk1_7pk_6',data={x:goo.x,y:goo.y[*,6]}
		

	
		options,'rbsp'+probe +'_fbk1_7pk_0','ytitle','pk!C'+fbk7_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7pk_1','ytitle','pk!C'+fbk7_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7pk_2','ytitle','pk!C'+fbk7_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7pk_3','ytitle','pk!C'+fbk7_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7pk_4','ytitle','pk!C'+fbk7_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7pk_5','ytitle','pk!C'+fbk7_bins[5]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7pk_6','ytitle','pk!C'+fbk7_bins[6]+'!CkHz!C[mV/m]'

		
		options,'rbsp'+probe +'_fbk1_7pk_0','labels','RBSP'+probe+'!C  '+fbk7_bins[0]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7pk_1','labels','RBSP'+probe+'!C  '+fbk7_bins[1]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7pk_2','labels','RBSP'+probe+'!C  '+fbk7_bins[2]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7pk_3','labels','RBSP'+probe+'!C  '+fbk7_bins[3]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7pk_4','labels','RBSP'+probe+'!C  '+fbk7_bins[4]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7pk_5','labels','RBSP'+probe+'!C  '+fbk7_bins[5]+'!CkHz'
		options,'rbsp'+probe +'_fbk1_7pk_6','labels','RBSP'+probe+'!C  '+fbk7_bins[6]+'!CkHz'
	
	
	
	endif
	
	get_data,'rbsp'+probe +'_efw_fbk_7_fb2_pk',data=goo
	tst = size(goo,/dimensions)
	if tst ne 0 then begin
		store_data,'rbsp'+probe +'_fbk2_7pk_0',data={x:goo.x,y:goo.y[*,0]}
		store_data,'rbsp'+probe +'_fbk2_7pk_1',data={x:goo.x,y:goo.y[*,1]}
		store_data,'rbsp'+probe +'_fbk2_7pk_2',data={x:goo.x,y:goo.y[*,2]}
		store_data,'rbsp'+probe +'_fbk2_7pk_3',data={x:goo.x,y:goo.y[*,3]}
		store_data,'rbsp'+probe +'_fbk2_7pk_4',data={x:goo.x,y:goo.y[*,4]}
		store_data,'rbsp'+probe +'_fbk2_7pk_5',data={x:goo.x,y:goo.y[*,5]}
		store_data,'rbsp'+probe +'_fbk2_7pk_6',data={x:goo.x,y:goo.y[*,6]}
		
		options,'rbsp'+probe +'_fbk2_7pk_0','ytitle','pk!C'+fbk7_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7pk_1','ytitle','pk!C'+fbk7_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7pk_2','ytitle','pk!C'+fbk7_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7pk_3','ytitle','pk!C'+fbk7_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7pk_4','ytitle','pk!C'+fbk7_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7pk_5','ytitle','pk!C'+fbk7_bins[5]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7pk_6','ytitle','pk!C'+fbk7_bins[6]+'!CkHz!C[mV/m]'

	

		
		options,'rbsp'+probe +'_fbk2_7pk_0','labels','RBSP'+probe+'!C  '+fbk7_bins[0]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7pk_1','labels','RBSP'+probe+'!C  '+fbk7_bins[1]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7pk_2','labels','RBSP'+probe+'!C  '+fbk7_bins[2]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7pk_3','labels','RBSP'+probe+'!C  '+fbk7_bins[3]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7pk_4','labels','RBSP'+probe+'!C  '+fbk7_bins[4]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7pk_5','labels','RBSP'+probe+'!C  '+fbk7_bins[5]+'!CkHz'
		options,'rbsp'+probe +'_fbk2_7pk_6','labels','RBSP'+probe+'!C  '+fbk7_bins[6]+'!CkHz'
		
	
	
		
	endif
	
	get_data,'rbsp'+probe +'_efw_fbk_13_fb1_av',data=goo
	tst = size(goo,/dimensions)
	if tst ne 0 then begin
		store_data,'rbsp'+probe +'_fbk1_13av_0',data={x:goo.x,y:goo.y[*,0]}
		store_data,'rbsp'+probe +'_fbk1_13av_1',data={x:goo.x,y:goo.y[*,1]}
		store_data,'rbsp'+probe +'_fbk1_13av_2',data={x:goo.x,y:goo.y[*,2]}
		store_data,'rbsp'+probe +'_fbk1_13av_3',data={x:goo.x,y:goo.y[*,3]}
		store_data,'rbsp'+probe +'_fbk1_13av_4',data={x:goo.x,y:goo.y[*,4]}
		store_data,'rbsp'+probe +'_fbk1_13av_5',data={x:goo.x,y:goo.y[*,5]}
		store_data,'rbsp'+probe +'_fbk1_13av_6',data={x:goo.x,y:goo.y[*,6]}
		store_data,'rbsp'+probe +'_fbk1_13av_7',data={x:goo.x,y:goo.y[*,7]}
		store_data,'rbsp'+probe +'_fbk1_13av_8',data={x:goo.x,y:goo.y[*,8]}
		store_data,'rbsp'+probe +'_fbk1_13av_9',data={x:goo.x,y:goo.y[*,9]}
		store_data,'rbsp'+probe +'_fbk1_13av_10',data={x:goo.x,y:goo.y[*,10]}
		store_data,'rbsp'+probe +'_fbk1_13av_11',data={x:goo.x,y:goo.y[*,11]}
		store_data,'rbsp'+probe +'_fbk1_13av_12',data={x:goo.x,y:goo.y[*,12]}
		

		options,'rbsp'+probe +'_fbk1_13av_0','ytitle','av!C'+fbk13_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_1','ytitle','av!C'+fbk13_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_2','ytitle','av!C'+fbk13_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_3','ytitle','av!C'+fbk13_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_4','ytitle','av!C'+fbk13_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_5','ytitle','av!C'+fbk13_bins[5]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_6','ytitle','av!C'+fbk13_bins[6]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_7','ytitle','av!C'+fbk13_bins[7]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_8','ytitle','av!C'+fbk13_bins[8]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_9','ytitle','av!C'+fbk13_bins[9]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_10','ytitle','av!C'+fbk13_bins[10]+'!CHkz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_11','ytitle','av!C'+fbk13_bins[11]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13av_12','ytitle','av!C'+fbk13_bins[12]+'!CkHz!C[mV/m]'


		
		options,'rbsp'+probe +'_fbk1_13av_0','labels','RBSP'+probe+'!C  '+fbk13_bins[0]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_1','labels','RBSP'+probe+'!C  '+fbk13_bins[1]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_2','labels','RBSP'+probe+'!C  '+fbk13_bins[2]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_3','labels','RBSP'+probe+'!C  '+fbk13_bins[3]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_4','labels','RBSP'+probe+'!C  '+fbk13_bins[4]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_5','labels','RBSP'+probe+'!C  '+fbk13_bins[5]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_6','labels','RBSP'+probe+'!C  '+fbk13_bins[6]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_7','labels','RBSP'+probe+'!C  '+fbk13_bins[7]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_8','labels','RBSP'+probe+'!C  '+fbk13_bins[8]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_9','labels','RBSP'+probe+'!C  '+fbk13_bins[9]+'!CHz'
		options,'rbsp'+probe +'_fbk1_13av_10','labels','RBSP'+probe+'!C  '+fbk13_bins[10]+'!CkHz'
		options,'rbsp'+probe +'_fbk1_13av_11','labels','RBSP'+probe+'!C  '+fbk13_bins[11]+'!CkHz'
		options,'rbsp'+probe +'_fbk1_13av_12','labels','RBSP'+probe+'!C  '+fbk13_bins[12]+'!CkHz'	


	
	endif
	
	get_data,'rbsp'+probe +'_efw_fbk_13_fb2_av',data=goo
	tst = size(goo,/dimensions)
	if tst ne 0 then begin
		store_data,'rbsp'+probe +'_fbk2_13av_0',data={x:goo.x,y:goo.y[*,0]}
		store_data,'rbsp'+probe +'_fbk2_13av_1',data={x:goo.x,y:goo.y[*,1]}
		store_data,'rbsp'+probe +'_fbk2_13av_2',data={x:goo.x,y:goo.y[*,2]}
		store_data,'rbsp'+probe +'_fbk2_13av_3',data={x:goo.x,y:goo.y[*,3]}
		store_data,'rbsp'+probe +'_fbk2_13av_4',data={x:goo.x,y:goo.y[*,4]}
		store_data,'rbsp'+probe +'_fbk2_13av_5',data={x:goo.x,y:goo.y[*,5]}
		store_data,'rbsp'+probe +'_fbk2_13av_6',data={x:goo.x,y:goo.y[*,6]}
		store_data,'rbsp'+probe +'_fbk2_13av_7',data={x:goo.x,y:goo.y[*,7]}
		store_data,'rbsp'+probe +'_fbk2_13av_8',data={x:goo.x,y:goo.y[*,8]}
		store_data,'rbsp'+probe +'_fbk2_13av_9',data={x:goo.x,y:goo.y[*,9]}
		store_data,'rbsp'+probe +'_fbk2_13av_10',data={x:goo.x,y:goo.y[*,10]}
		store_data,'rbsp'+probe +'_fbk2_13av_11',data={x:goo.x,y:goo.y[*,11]}
		store_data,'rbsp'+probe +'_fbk2_13av_12',data={x:goo.x,y:goo.y[*,12]}
		

		options,'rbsp'+probe +'_fbk2_13av_0','ytitle','av!C'+fbk13_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_1','ytitle','av!C'+fbk13_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_2','ytitle','av!C'+fbk13_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_3','ytitle','av!C'+fbk13_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_4','ytitle','av!C'+fbk13_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_5','ytitle','av!C'+fbk13_bins[5]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_6','ytitle','av!C'+fbk13_bins[6]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_7','ytitle','av!C'+fbk13_bins[7]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_8','ytitle','av!C'+fbk13_bins[8]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_9','ytitle','av!C'+fbk13_bins[9]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_10','ytitle','av!C'+fbk13_bins[10]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_11','ytitle','av!C'+fbk13_bins[11]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13av_12','ytitle','av!C'+fbk13_bins[12]+'!CkHz!C[mV/m]'

		
		options,'rbsp'+probe +'_fbk2_13av_0','labels','RBSP'+probe+'!C  '+fbk13_bins[0]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_1','labels','RBSP'+probe+'!C  '+fbk13_bins[1]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_2','labels','RBSP'+probe+'!C  '+fbk13_bins[2]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_3','labels','RBSP'+probe+'!C  '+fbk13_bins[3]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_4','labels','RBSP'+probe+'!C  '+fbk13_bins[4]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_5','labels','RBSP'+probe+'!C  '+fbk13_bins[5]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_6','labels','RBSP'+probe+'!C  '+fbk13_bins[6]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_7','labels','RBSP'+probe+'!C  '+fbk13_bins[7]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_8','labels','RBSP'+probe+'!C  '+fbk13_bins[8]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_9','labels','RBSP'+probe+'!C  '+fbk13_bins[9]+'!CHz'
		options,'rbsp'+probe +'_fbk2_13av_10','labels','RBSP'+probe+'!C  '+fbk13_bins[10]+'!CkHz'
		options,'rbsp'+probe +'_fbk2_13av_11','labels','RBSP'+probe+'!C  '+fbk13_bins[11]+'!CkHz'
		options,'rbsp'+probe +'_fbk2_13av_12','labels','RBSP'+probe+'!C  '+fbk13_bins[12]+'!CkHz'	
	
	endif
	
	get_data,'rbsp'+probe +'_efw_fbk_7_fb1_av',data=goo
	tst = size(goo,/dimensions)
	if tst ne 0 then begin
		store_data,'rbsp'+probe +'_fbk1_7av_0',data={x:goo.x,y:goo.y[*,0]}
		store_data,'rbsp'+probe +'_fbk1_7av_1',data={x:goo.x,y:goo.y[*,1]}
		store_data,'rbsp'+probe +'_fbk1_7av_2',data={x:goo.x,y:goo.y[*,2]}
		store_data,'rbsp'+probe +'_fbk1_7av_3',data={x:goo.x,y:goo.y[*,3]}
		store_data,'rbsp'+probe +'_fbk1_7av_4',data={x:goo.x,y:goo.y[*,4]}
		store_data,'rbsp'+probe +'_fbk1_7av_5',data={x:goo.x,y:goo.y[*,5]}
		store_data,'rbsp'+probe +'_fbk1_7av_6',data={x:goo.x,y:goo.y[*,6]}
		

		options,'rbsp'+probe +'_fbk1_7av_0','ytitle','av!C'+fbk7_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7av_1','ytitle','av!C'+fbk7_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7av_2','ytitle','av!C'+fbk7_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7av_3','ytitle','av!C'+fbk7_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7av_4','ytitle','av!C'+fbk7_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7av_5','ytitle','av!C'+fbk7_bins[5]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7av_6','ytitle','av!C'+fbk7_bins[6]+'!CkHz!C[mV/m]'

		
		options,'rbsp'+probe +'_fbk1_7av_0','labels','RBSP'+probe+'!C  '+fbk7_bins[0]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7av_1','labels','RBSP'+probe+'!C  '+fbk7_bins[1]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7av_2','labels','RBSP'+probe+'!C  '+fbk7_bins[2]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7av_3','labels','RBSP'+probe+'!C  '+fbk7_bins[3]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7av_4','labels','RBSP'+probe+'!C  '+fbk7_bins[4]+'!CHz'
		options,'rbsp'+probe +'_fbk1_7av_5','labels','RBSP'+probe+'!C  '+fbk7_bins[5]+'!CkHz'
		options,'rbsp'+probe +'_fbk1_7av_6','labels','RBSP'+probe+'!C  '+fbk7_bins[6]+'!CkHz'

	
	
	endif
	
	get_data,'rbsp'+probe +'_efw_fbk_7_fb2_av',data=goo
	tst = size(goo,/dimensions)
	if tst ne 0 then begin
		store_data,'rbsp'+probe +'_fbk2_7av_0',data={x:goo.x,y:goo.y[*,0]}
		store_data,'rbsp'+probe +'_fbk2_7av_1',data={x:goo.x,y:goo.y[*,1]}
		store_data,'rbsp'+probe +'_fbk2_7av_2',data={x:goo.x,y:goo.y[*,2]}
		store_data,'rbsp'+probe +'_fbk2_7av_3',data={x:goo.x,y:goo.y[*,3]}
		store_data,'rbsp'+probe +'_fbk2_7av_4',data={x:goo.x,y:goo.y[*,4]}
		store_data,'rbsp'+probe +'_fbk2_7av_5',data={x:goo.x,y:goo.y[*,5]}
		store_data,'rbsp'+probe +'_fbk2_7av_6',data={x:goo.x,y:goo.y[*,6]}
		

		options,'rbsp'+probe +'_fbk2_7av_0','ytitle','av!C'+fbk7_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7av_1','ytitle','av!C'+fbk7_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7av_2','ytitle','av!C'+fbk7_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7av_3','ytitle','av!C'+fbk7_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7av_4','ytitle','av!C'+fbk7_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7av_5','ytitle','av!C'+fbk7_bins[5]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7av_6','ytitle','av!C'+fbk7_bins[6]+'!CkHz!C[mV/m]'

		
		options,'rbsp'+probe +'_fbk2_7av_0','labels','RBSP'+probe+'!C  '+fbk7_bins[0]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7av_1','labels','RBSP'+probe+'!C  '+fbk7_bins[1]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7av_2','labels','RBSP'+probe+'!C  '+fbk7_bins[2]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7av_3','labels','RBSP'+probe+'!C  '+fbk7_bins[3]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7av_4','labels','RBSP'+probe+'!C  '+fbk7_bins[4]+'!CHz'
		options,'rbsp'+probe +'_fbk2_7av_5','labels','RBSP'+probe+'!C  '+fbk7_bins[5]+'!CkHz'
		options,'rbsp'+probe +'_fbk2_7av_6','labels','RBSP'+probe+'!C  '+fbk7_bins[6]+'!CkHz'

		
	endif
	
	
	
	if keyword_set(combine) then begin
	
		;Combine FBK pk and av quantities onto a single plot
		
		
		store_data,'rbsp'+probe +'_fbk1_13comb_0',data=['rbsp'+probe +'_fbk1_13pk_0','rbsp'+probe +'_fbk1_13av_0']
		store_data,'rbsp'+probe +'_fbk1_13comb_1',data=['rbsp'+probe +'_fbk1_13pk_1','rbsp'+probe +'_fbk1_13av_1']
		store_data,'rbsp'+probe +'_fbk1_13comb_2',data=['rbsp'+probe +'_fbk1_13pk_2','rbsp'+probe +'_fbk1_13av_2']
		store_data,'rbsp'+probe +'_fbk1_13comb_3',data=['rbsp'+probe +'_fbk1_13pk_3','rbsp'+probe +'_fbk1_13av_3']
		store_data,'rbsp'+probe +'_fbk1_13comb_4',data=['rbsp'+probe +'_fbk1_13pk_4','rbsp'+probe +'_fbk1_13av_4']
		store_data,'rbsp'+probe +'_fbk1_13comb_5',data=['rbsp'+probe +'_fbk1_13pk_5','rbsp'+probe +'_fbk1_13av_5']
		store_data,'rbsp'+probe +'_fbk1_13comb_6',data=['rbsp'+probe +'_fbk1_13pk_6','rbsp'+probe +'_fbk1_13av_6']
		store_data,'rbsp'+probe +'_fbk1_13comb_7',data=['rbsp'+probe +'_fbk1_13pk_7','rbsp'+probe +'_fbk1_13av_7']
		store_data,'rbsp'+probe +'_fbk1_13comb_8',data=['rbsp'+probe +'_fbk1_13pk_8','rbsp'+probe +'_fbk1_13av_8']
		store_data,'rbsp'+probe +'_fbk1_13comb_9',data=['rbsp'+probe +'_fbk1_13pk_9','rbsp'+probe +'_fbk1_13av_9']
		store_data,'rbsp'+probe +'_fbk1_13comb_10',data=['rbsp'+probe +'_fbk1_13pk_10','rbsp'+probe +'_fbk1_13av_10']
		store_data,'rbsp'+probe +'_fbk1_13comb_11',data=['rbsp'+probe +'_fbk1_13pk_11','rbsp'+probe +'_fbk1_13av_11']
		store_data,'rbsp'+probe +'_fbk1_13comb_12',data=['rbsp'+probe +'_fbk1_13pk_12','rbsp'+probe +'_fbk1_13av_12']
		
		
		
		store_data,'rbsp'+probe +'_fbk2_13comb_0',data=['rbsp'+probe +'_fbk2_13pk_0','rbsp'+probe +'_fbk2_13av_0']
		store_data,'rbsp'+probe +'_fbk2_13comb_1',data=['rbsp'+probe +'_fbk2_13pk_1','rbsp'+probe +'_fbk2_13av_1']
		store_data,'rbsp'+probe +'_fbk2_13comb_2',data=['rbsp'+probe +'_fbk2_13pk_2','rbsp'+probe +'_fbk2_13av_2']
		store_data,'rbsp'+probe +'_fbk2_13comb_3',data=['rbsp'+probe +'_fbk2_13pk_3','rbsp'+probe +'_fbk2_13av_3']
		store_data,'rbsp'+probe +'_fbk2_13comb_4',data=['rbsp'+probe +'_fbk2_13pk_4','rbsp'+probe +'_fbk2_13av_4']
		store_data,'rbsp'+probe +'_fbk2_13comb_5',data=['rbsp'+probe +'_fbk2_13pk_5','rbsp'+probe +'_fbk2_13av_5']
		store_data,'rbsp'+probe +'_fbk2_13comb_6',data=['rbsp'+probe +'_fbk2_13pk_6','rbsp'+probe +'_fbk2_13av_6']
		store_data,'rbsp'+probe +'_fbk2_13comb_7',data=['rbsp'+probe +'_fbk2_13pk_7','rbsp'+probe +'_fbk2_13av_7']
		store_data,'rbsp'+probe +'_fbk2_13comb_8',data=['rbsp'+probe +'_fbk2_13pk_8','rbsp'+probe +'_fbk2_13av_8']
		store_data,'rbsp'+probe +'_fbk2_13comb_9',data=['rbsp'+probe +'_fbk2_13pk_9','rbsp'+probe +'_fbk2_13av_9']
		store_data,'rbsp'+probe +'_fbk2_13comb_10',data=['rbsp'+probe +'_fbk2_13pk_10','rbsp'+probe +'_fbk2_13av_10']
		store_data,'rbsp'+probe +'_fbk2_13comb_11',data=['rbsp'+probe +'_fbk2_13pk_11','rbsp'+probe +'_fbk2_13av_11']
		store_data,'rbsp'+probe +'_fbk2_13comb_12',data=['rbsp'+probe +'_fbk2_13pk_12','rbsp'+probe +'_fbk2_13av_12']
		
		
		
		store_data,'rbsp'+probe +'_fbk1_7comb_0',data=['rbsp'+probe +'_fbk1_7pk_0','rbsp'+probe +'_fbk1_7av_0']
		store_data,'rbsp'+probe +'_fbk1_7comb_1',data=['rbsp'+probe +'_fbk1_7pk_1','rbsp'+probe +'_fbk1_7av_1']
		store_data,'rbsp'+probe +'_fbk1_7comb_2',data=['rbsp'+probe +'_fbk1_7pk_2','rbsp'+probe +'_fbk1_7av_2']
		store_data,'rbsp'+probe +'_fbk1_7comb_3',data=['rbsp'+probe +'_fbk1_7pk_3','rbsp'+probe +'_fbk1_7av_3']
		store_data,'rbsp'+probe +'_fbk1_7comb_4',data=['rbsp'+probe +'_fbk1_7pk_4','rbsp'+probe +'_fbk1_7av_4']
		store_data,'rbsp'+probe +'_fbk1_7comb_5',data=['rbsp'+probe +'_fbk1_7pk_5','rbsp'+probe +'_fbk1_7av_5']
		store_data,'rbsp'+probe +'_fbk1_7comb_6',data=['rbsp'+probe +'_fbk1_7pk_6','rbsp'+probe +'_fbk1_7av_6']
		
		
		store_data,'rbsp'+probe +'_fbk2_7comb_0',data=['rbsp'+probe +'_fbk2_7pk_0','rbsp'+probe +'_fbk2_7av_0']
		store_data,'rbsp'+probe +'_fbk2_7comb_1',data=['rbsp'+probe +'_fbk2_7pk_1','rbsp'+probe +'_fbk2_7av_1']
		store_data,'rbsp'+probe +'_fbk2_7comb_2',data=['rbsp'+probe +'_fbk2_7pk_2','rbsp'+probe +'_fbk2_7av_2']
		store_data,'rbsp'+probe +'_fbk2_7comb_3',data=['rbsp'+probe +'_fbk2_7pk_3','rbsp'+probe +'_fbk2_7av_3']
		store_data,'rbsp'+probe +'_fbk2_7comb_4',data=['rbsp'+probe +'_fbk2_7pk_4','rbsp'+probe +'_fbk2_7av_4']
		store_data,'rbsp'+probe +'_fbk2_7comb_5',data=['rbsp'+probe +'_fbk2_7pk_5','rbsp'+probe +'_fbk2_7av_5']
		store_data,'rbsp'+probe +'_fbk2_7comb_6',data=['rbsp'+probe +'_fbk2_7pk_6','rbsp'+probe +'_fbk2_7av_6']
		




		;Change colors to black and red
		options,['rbsp'+probe+'_fbk1_13comb_0',$
				 'rbsp'+probe+'_fbk1_13comb_1',$
				 'rbsp'+probe+'_fbk1_13comb_2',$
				 'rbsp'+probe+'_fbk1_13comb_3',$
				 'rbsp'+probe+'_fbk1_13comb_4',$
				 'rbsp'+probe+'_fbk1_13comb_5',$
				 'rbsp'+probe+'_fbk1_13comb_6',$
				 'rbsp'+probe+'_fbk1_13comb_7',$
				 'rbsp'+probe+'_fbk1_13comb_8',$
				 'rbsp'+probe+'_fbk1_13comb_9',$
				 'rbsp'+probe+'_fbk1_13comb_10',$
				 'rbsp'+probe+'_fbk1_13comb_11',$
				 'rbsp'+probe+'_fbk1_13comb_12'],colors=[0,6]
		
		
		options,['rbsp'+probe+'_fbk2_13comb_0',$
				 'rbsp'+probe+'_fbk2_13comb_1',$
				 'rbsp'+probe+'_fbk2_13comb_2',$
				 'rbsp'+probe+'_fbk2_13comb_3',$
		 		 'rbsp'+probe+'_fbk2_13comb_4',$
		 		 'rbsp'+probe+'_fbk2_13comb_5',$
		 		 'rbsp'+probe+'_fbk2_13comb_6',$
		 		 'rbsp'+probe+'_fbk2_13comb_7',$
				 'rbsp'+probe+'_fbk2_13comb_8',$
				 'rbsp'+probe+'_fbk2_13comb_9',$
				 'rbsp'+probe+'_fbk2_13comb_10',$
				 'rbsp'+probe+'_fbk2_13comb_11',$
				 'rbsp'+probe+'_fbk2_13comb_12'],colors=[0,6]
		
		
		options,['rbsp'+probe+'_fbk1_7comb_0',$
			     'rbsp'+probe+'_fbk1_7comb_1',$
			     'rbsp'+probe+'_fbk1_7comb_2',$
			     'rbsp'+probe+'_fbk1_7comb_3',$
				 'rbsp'+probe+'_fbk1_7comb_4',$
				 'rbsp'+probe+'_fbk1_7comb_5',$
				 'rbsp'+probe+'_fbk1_7comb_6'],colors=[0,6]
		
		
		options,['rbsp'+probe+'_fbk2_7comb_0',$
				 'rbsp'+probe+'_fbk2_7comb_1',$
				 'rbsp'+probe+'_fbk2_7comb_2',$
				 'rbsp'+probe+'_fbk2_7comb_3',$
				 'rbsp'+probe+'_fbk2_7comb_4',$
				 'rbsp'+probe+'_fbk2_7comb_5',$
				 'rbsp'+probe+'_fbk2_7comb_6'],colors=[0,6]
		
	
	
	
	
			
	
		options,'rbsp'+probe+'_fbk?_??comb*','labels',['','']
	

	
	
		options,'rbsp'+probe +'_fbk1_13comb_0','ytitle',fbk13_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_1','ytitle',fbk13_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_2','ytitle',fbk13_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_3','ytitle',fbk13_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_4','ytitle',fbk13_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_5','ytitle',fbk13_bins[5]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_6','ytitle',fbk13_bins[6]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_7','ytitle',fbk13_bins[7]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_8','ytitle',fbk13_bins[8]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_9','ytitle',fbk13_bins[9]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_10','ytitle',fbk13_bins[10]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_11','ytitle',fbk13_bins[11]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_13comb_12','ytitle',fbk13_bins[12]+'!CkHz!C[mV/m]'
	
		options,'rbsp'+probe +'_fbk2_13comb_0','ytitle',fbk13_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_1','ytitle',fbk13_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_2','ytitle',fbk13_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_3','ytitle',fbk13_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_4','ytitle',fbk13_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_5','ytitle',fbk13_bins[5]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_6','ytitle',fbk13_bins[6]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_7','ytitle',fbk13_bins[7]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_8','ytitle',fbk13_bins[8]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_9','ytitle',fbk13_bins[9]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_10','ytitle',fbk13_bins[10]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_11','ytitle',fbk13_bins[11]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_13comb_12','ytitle',fbk13_bins[12]+'!CkHz!C[mV/m]'
	
		options,'rbsp'+probe +'_fbk1_7comb_0','ytitle',fbk7_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7comb_1','ytitle',fbk7_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7comb_2','ytitle',fbk7_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7comb_3','ytitle',fbk7_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7comb_4','ytitle',fbk7_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7comb_5','ytitle',fbk7_bins[5]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk1_7comb_6','ytitle',fbk7_bins[6]+'!CkHz!C[mV/m]'
	
	
		options,'rbsp'+probe +'_fbk2_7comb_0','ytitle',fbk7_bins[0]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7comb_1','ytitle',fbk7_bins[1]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7comb_2','ytitle',fbk7_bins[2]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7comb_3','ytitle',fbk7_bins[3]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7comb_4','ytitle',fbk7_bins[4]+'!CHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7comb_5','ytitle',fbk7_bins[5]+'!CkHz!C[mV/m]'
		options,'rbsp'+probe +'_fbk2_7comb_6','ytitle',fbk7_bins[6]+'!CkHz!C[mV/m]'
	
	
		
		

	endif	


;The number of y-ticks is usually too large when 7 or 13 plots are displayed at once. 
;Unfortunately reducing the tick numbers means that negative numbers show up. So, I have
;to manually set the yrange
options,'rbsp'+probe+'_fbk1_13pk_*','yticks',2

get_data,'rbsp'+probe +'_fbk1_13pk_0',data=goo0
get_data,'rbsp'+probe +'_fbk1_13pk_1',data=goo1
get_data,'rbsp'+probe +'_fbk1_13pk_2',data=goo2
get_data,'rbsp'+probe +'_fbk1_13pk_3',data=goo3
get_data,'rbsp'+probe +'_fbk1_13pk_4',data=goo4
get_data,'rbsp'+probe +'_fbk1_13pk_5',data=goo5
get_data,'rbsp'+probe +'_fbk1_13pk_6',data=goo6
get_data,'rbsp'+probe +'_fbk1_13pk_7',data=goo7
get_data,'rbsp'+probe +'_fbk1_13pk_8',data=goo8
get_data,'rbsp'+probe +'_fbk1_13pk_9',data=goo9
get_data,'rbsp'+probe +'_fbk1_13pk_10',data=goo10
get_data,'rbsp'+probe +'_fbk1_13pk_11',data=goo11
get_data,'rbsp'+probe +'_fbk1_13pk_12',data=goo12


ylim,'rbsp'+probe +'_fbk1_13pk_0',0,max(goo0.y)
ylim,'rbsp'+probe +'_fbk1_13pk_1',0,max(goo1.y)
ylim,'rbsp'+probe +'_fbk1_13pk_2',0,max(goo2.y)
ylim,'rbsp'+probe +'_fbk1_13pk_3',0,max(goo3.y)
ylim,'rbsp'+probe +'_fbk1_13pk_4',0,max(goo4.y)
ylim,'rbsp'+probe +'_fbk1_13pk_5',0,max(goo5.y)
ylim,'rbsp'+probe +'_fbk1_13pk_6',0,max(goo6.y)
ylim,'rbsp'+probe +'_fbk1_13pk_7',0,max(goo7.y)
ylim,'rbsp'+probe +'_fbk1_13pk_8',0,max(goo8.y)
ylim,'rbsp'+probe +'_fbk1_13pk_9',0,max(goo9.y)
ylim,'rbsp'+probe +'_fbk1_13pk_10',0,max(goo10.y)
ylim,'rbsp'+probe +'_fbk1_13pk_11',0,max(goo11.y)
ylim,'rbsp'+probe +'_fbk1_13pk_12',0,max(goo12.y)


;Keep only 1 number after decimal place. More just clutters up plot
options,'rbsp'+probe +'_fbk1_13pk_0','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_1','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_2','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_3','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_4','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_5','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_6','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_7','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_8','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_9','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_10','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_11','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_12','ytickformat','(f6.1)'



;The number of y-ticks is usually too large when 7 or 13 plots are displayed at once. 
;Unfortunately reducing the tick numbers means that negative numbers show up. So, I have
;to manually set the yrange
options,'rbspa_fbk1_13pk_*','yticks',2

get_data,'rbsp'+probe +'_fbk1_13pk_0',data=goo0
get_data,'rbsp'+probe +'_fbk1_13pk_1',data=goo1
get_data,'rbsp'+probe +'_fbk1_13pk_2',data=goo2
get_data,'rbsp'+probe +'_fbk1_13pk_3',data=goo3
get_data,'rbsp'+probe +'_fbk1_13pk_4',data=goo4
get_data,'rbsp'+probe +'_fbk1_13pk_5',data=goo5
get_data,'rbsp'+probe +'_fbk1_13pk_6',data=goo6
get_data,'rbsp'+probe +'_fbk1_13pk_7',data=goo7
get_data,'rbsp'+probe +'_fbk1_13pk_8',data=goo8
get_data,'rbsp'+probe +'_fbk1_13pk_9',data=goo9
get_data,'rbsp'+probe +'_fbk1_13pk_10',data=goo10
get_data,'rbsp'+probe +'_fbk1_13pk_11',data=goo11
get_data,'rbsp'+probe +'_fbk1_13pk_12',data=goo12


ylim,'rbsp'+probe +'_fbk1_13pk_0',0,max(goo0.y)
ylim,'rbsp'+probe +'_fbk1_13pk_1',0,max(goo1.y)
ylim,'rbsp'+probe +'_fbk1_13pk_2',0,max(goo2.y)
ylim,'rbsp'+probe +'_fbk1_13pk_3',0,max(goo3.y)
ylim,'rbsp'+probe +'_fbk1_13pk_4',0,max(goo4.y)
ylim,'rbsp'+probe +'_fbk1_13pk_5',0,max(goo5.y)
ylim,'rbsp'+probe +'_fbk1_13pk_6',0,max(goo6.y)
ylim,'rbsp'+probe +'_fbk1_13pk_7',0,max(goo7.y)
ylim,'rbsp'+probe +'_fbk1_13pk_8',0,max(goo8.y)
ylim,'rbsp'+probe +'_fbk1_13pk_9',0,max(goo9.y)
ylim,'rbsp'+probe +'_fbk1_13pk_10',0,max(goo10.y)
ylim,'rbsp'+probe +'_fbk1_13pk_11',0,max(goo11.y)
ylim,'rbsp'+probe +'_fbk1_13pk_12',0,max(goo12.y)


;Keep only 1 number after decimal place. More just clutters up plot
options,'rbsp'+probe +'_fbk1_13pk_0','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_1','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_2','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_3','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_4','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_5','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_6','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_7','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_8','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_9','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_10','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_11','ytickformat','(f6.1)'
options,'rbsp'+probe +'_fbk1_13pk_12','ytickformat','(f6.1)'


	


	

end