;RBSP vxB subtraction routine

;Input: tplot variable names. These variables should contain
;	velocity, mag and E-field data in MGSE coord. 
;	To get these quantities in MGSE first use cotrans to go from
;	whatever coord system to GSE. Then use rbsp_gse2mgse.pro to go
;	to MGSE

;Written by Aaron W Breneman   11/2012



pro rbsp_vxb_subtract,velname,magname,esvyname


get_data,velname,data=vel
get_data,magname,data=mag
get_data,esvyname,data=esvy


;Interpolate data to be on same cadence
mag1 = interpol(mag.y[*,0],mag.x,esvy.x)/1d9
mag2 = interpol(mag.y[*,1],mag.x,esvy.x)/1d9
mag3 = interpol(mag.y[*,2],mag.x,esvy.x)/1d9

vel1 = interpol(vel.y[*,0],vel.x,esvy.x)*1d6
vel2 = interpol(vel.y[*,1],vel.x,esvy.x)*1d6
vel3 = interpol(vel.y[*,2],vel.x,esvy.x)*1d6



;Calculate the vxB components.
vxB_x = (vel2*mag3 - vel3*mag2)
vxB_y = (vel3*mag1 - vel1*mag3)
vxB_z = (vel1*mag2 - vel2*mag1)


store_data,'vxb_x',data={x:esvy.x,y:vxb_x}
store_data,'vxb_y',data={x:esvy.x,y:vxb_y}
store_data,'vxb_z',data={x:esvy.x,y:vxb_z}

options,'vxb_x','ytitle','-(vxB)!CmV/m!CMGSEx'
options,'vxb_y','ytitle','-(vxB)!CmV/m!CMGSEy'
options,'vxb_z','ytitle','-(vxB)!CmV/m!CMGSEz'

;ylim,'vxb_x',-200,200
;ylim,'vxb_y',-200,200
;ylim,'vxb_z',-200,200
;ylim,'rbsp'+sc+'_efw_esvy_MGSE',-200,200

;tplot,['vxb_x','vxb_y','vxb_z','rbsp'+sc+'_efw_esvy_MGSE'];,'mag2','vel2']


;---------------------------------------
;E - vxB
;---------------------------------------

;get_data,'rbsp'+sc+'_efw_esvy_MGSE',data=esvyvals

diffx = esvy.y[*,0] - vxB_x
diffy = esvy.y[*,1] - vxB_y
diffz = esvy.y[*,2] - vxB_z

;store_data,'Ex_mgse_vxb_removed',data={x:esvy.x,y:diffx}
;store_data,'Ey_mgse_vxb_removed',data={x:esvy.x,y:diffy}
;store_data,'Ez_mgse_vxb_removed',data={x:esvy.x,y:diffz}

store_data,'Esvy_mgse_vxb_removed',data={x:esvy.x,y:[[diffx],[diffy],[diffz]]}


;tplot,['Ex_mgse_vxb_removed','Ey_mgse_vxb_removed','Ez_mgse_vxb_removed']



velmag = sqrt(vxB_x^2 + vxB_y^2 + vxB_z^2)
store_data,'vxbmag',data={x:mag.x,y:velmag}



;store_data,'magx',data={x:mag.x,y:mag1}
;store_data,'magy',data={x:mag.x,y:mag2}
;store_data,'magz',data={x:mag.x,y:mag3}

;store_data,'velx',data={x:mag.x,y:vel1}
;store_data,'vely',data={x:mag.x,y:vel2}
;store_data,'velz',data={x:mag.x,y:vel3}


;tplot,['magx','magy','magz']
;tplot,['velx','vely','velz','vel']


;get_data,'vel',data=vell

;store_data,'velgsex',data={x:vell.x,y:vell.y[*,0]*1d6}
;store_data,'velgsey',data={x:vell.x,y:vell.y[*,1]*1d6}
;store_data,'velgsez',data={x:vell.x,y:vell.y[*,1]*1d6}


;store_data,'xcomb',data=['velgsex','velx']
;tplot,['velgsex','velx']



end